summaryrefslogtreecommitdiffstats
path: root/tdeui/kaction.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2012-10-20 20:30:14 -0500
committerTimothy Pearson <[email protected]>2012-10-20 20:30:14 -0500
commitfe43761567120b0bda4e0aed56b7c1e56bdd93c5 (patch)
treefb23cd5905748c6e495f65a689cdd446fa3e4cae /tdeui/kaction.h
parent481457e5859adea2b83aba47b6d5d724b4c7bf24 (diff)
downloadtdelibs-fe43761567120b0bda4e0aed56b7c1e56bdd93c5.tar.gz
tdelibs-fe43761567120b0bda4e0aed56b7c1e56bdd93c5.zip
Update TQt3 property/enum macros
Diffstat (limited to 'tdeui/kaction.h')
-rw-r--r--tdeui/kaction.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/tdeui/kaction.h b/tdeui/kaction.h
index 44e77a4d5..dca99b4b0 100644
--- a/tdeui/kaction.h
+++ b/tdeui/kaction.h
@@ -203,15 +203,15 @@ class TDEUI_EXPORT KAction : public TQObject
{
friend class KActionCollection;
Q_OBJECT
- Q_PROPERTY( int containerCount READ containerCount )
- Q_PROPERTY( TQString plainText READ plainText )
- Q_PROPERTY( TQString text READ text WRITE setText )
- Q_PROPERTY( TQString shortcut READ shortcutText WRITE setShortcutText )
- Q_PROPERTY( bool enabled READ isEnabled WRITE setEnabled )
- Q_PROPERTY( TQString group READ group WRITE setGroup )
- Q_PROPERTY( TQString whatsThis READ whatsThis WRITE setWhatsThis )
- Q_PROPERTY( TQString toolTip READ toolTip WRITE setToolTip )
- Q_PROPERTY( TQString icon READ icon WRITE setIcon )
+ TQ_PROPERTY( int containerCount READ containerCount )
+ TQ_PROPERTY( TQString plainText READ plainText )
+ TQ_PROPERTY( TQString text READ text WRITE setText )
+ TQ_PROPERTY( TQString shortcut READ shortcutText WRITE setShortcutText )
+ TQ_PROPERTY( bool enabled READ isEnabled WRITE setEnabled )
+ TQ_PROPERTY( TQString group READ group WRITE setGroup )
+ TQ_PROPERTY( TQString whatsThis READ whatsThis WRITE setWhatsThis )
+ TQ_PROPERTY( TQString toolTip READ toolTip WRITE setToolTip )
+ TQ_PROPERTY( TQString icon READ icon WRITE setIcon )
public:
/**
* Constructs an action with text, potential keyboard
@@ -436,7 +436,7 @@ public:
*/
virtual const KShortcut& shortcutDefault() const;
// These two methods are for Q_PROPERTY
TQString shortcutText() const;
void setShortcutText( const TQString& );
@@ -436,7 +436,7 @@ public:
*/
virtual const KShortcut& shortcutDefault() const;
- // These two methods are for Q_PROPERTY
+ // These two methods are for TQ_PROPERTY
TQString shortcutText() const;
void setShortcutText( const TQString& );